| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
Data.Text.PgpWordlist.Internal.Types
- newtype PgpWordlist = PgpWordlist (AltList EvenWord OddWord)
- data TranslationError
- newtype EvenWord = EvenWord {
- unEvenWord :: Text
- newtype OddWord = OddWord {
- unOddWord :: Text
Documentation
newtype PgpWordlist Source #
Abstract representation of a PGP word list.
Constructors
| PgpWordlist (AltList EvenWord OddWord) |
Instances
data TranslationError Source #
Possible translation errors from a list of PGP words to binary format.
Constructors
| BadWord Text | Word is not recognized |
| BadParity Text Word8 | Word is recognized, but from the wrong alphabet. Duplicates, omissions, and neighbour transpositions are often cause for this. |
Instances
Word that is supposed to occur in an even position
Constructors
| EvenWord | |
Fields
| |